@@ -1,18 +1,25 @@
 #![allow(bad_style)]
 
-extern crate core_foundation_sys;
-
-#[cfg_attr(any(target_os = "macos", target_os = "ios"), link(name = "Security", kind = "framework"))]
+#[cfg_attr(
+    any(target_os = "macos", target_os = "ios", target_os = "tvos", target_os = "watchos"),
+    link(name = "Security", kind = "framework")
+)]
 extern "C" {}
 
 #[cfg(target_os = "macos")]
 pub mod access;
+pub mod access_control;
+#[cfg(target_os = "macos")]
+pub mod authorization;
 pub mod base;
+#[cfg(any(target_os = "macos", target_os = "ios", target_os = "tvos", target_os = "watchos"))]
 pub mod certificate;
 #[cfg(target_os = "macos")]
 pub mod certificate_oids;
 pub mod cipher_suite;
 #[cfg(target_os = "macos")]
+pub mod code_signing;
+#[cfg(target_os = "macos")]
 pub mod digest_transform;
 #[cfg(target_os = "macos")]
 pub mod encrypt_transform;
@@ -20,9 +27,7 @@ pub mod identity;
 pub mod import_export;
 pub mod item;
 pub mod key;
-#[cfg(target_os = "macos")]
 pub mod keychain;
-#[cfg(target_os = "macos")]
 pub mod keychain_item;
 pub mod policy;
 pub mod random;
